==> litejs-18.12.2.tgz: package/lib/template/default/ui/js/app.js <==


xhr.logErrors = function(unsentErrors) {
	xhr("POST", "/errlog").send(JSON.stringify(unsentErrors))
	unsentErrors.length = 0
}


// Clickjacking defense, break out of frames.
// If JavaScript is disabled, the site will not display at all.
if (self !== top) {
	xhr.logErrors(["Framed in " + top.location])
	throw top.location = self.location
}


!function(document, navigator, View, i18n) {
	i18n.def({
		"en": "In English"
	})

	var timezone
	, html = document.documentElement
	, body = document.body
	, link = /./
	, standalone = "standalone" in navigator ?
		navigator.standalone :
		this.matchMedia && matchMedia("(display-mode:standalone)").matches

	// Detect first available language
	, lang = i18n.use([].concat(
		navigator.languages, navigator.language, navigator.userLanguage,
		"en" // Default language
	).filter(i18n.get)[0])

	// Detect base from HTML <base> element
	, base = (html.getElementsByTagName("base")[0] || i18n).href


	history.scrollRestoration = "manual"

	try {
		timezone = Intl.DateTimeFormat().resolvedOptions().timezone
	} catch(e) {}

	i18n.setLang = function(lang) {
		html.lang = lang = i18n.use(lang)
		xhr.load("lang/" + lang + ".js", function() {
			Date.names = i18n("__date").split(" ")
			String.alphabet = i18n("__alphabet")
			String.ordinal = i18n("__ordinal")
			String.plural = i18n("__plural")
			Object.assign(Date.masks, i18n("__dateMasks"))
			body.dir = i18n("dir")

			El.render(body)
		})
	}


	// Define `#body` view, it is a starting point for us.
	// It could be any element on page but we want to start from `BODY`.
	View("#body", body)

	View.on("show", function(params, view) {
		// Re-render all .js-viewHook elements on each View change
		El.findAll(body, ".js-viewRender").render()
		scroll(0, 0)
	})

	if (standalone) {
		El.addClass(html, "is-app")
	}


	xhr.load(El.findAll(body, "script[type='litejs/view']").pluck("src"), function() {
		// Start a router to show views
		history.start(View.show, base && base.replace(/.*:\/\/[^/]*|[^\/]*$/g, ""))
	})

	if (this.console && console.log) {
		link.toString = function() {
			return "https://en.wikipedia.org/wiki/Self-XSS"
		}
		console.log(
			"%cStop!\n%cThis developer tool lets you hack and give others access only to your own account.\nSee %s for more information.",
			"font:bold 50px monospace;color:red;text-shadow:3px 3px #000,-1px -1px #fff",
			"font:20px sans-serif",
			link
		)
	}
}(document, navigator, View, El.i18n)

==> litejs-19.2.0.tgz: package/lib/template/default/ui/js/app.js <==


xhr.logErrors = function(unsentErrors) {
	xhr("POST", "/errlog").send(JSON.stringify(unsentErrors))
	unsentErrors.length = 0
}


// Clickjacking defense, break out of frames.
// If JavaScript is disabled, the site will not display at all.
if (self !== top) {
	xhr.logErrors(["Framed in " + top.location])
	throw top.location = self.location
}


!function(window, document, navigator, View, i18n) {
	i18n.def({
		"en": "In English"
	})

	var timezone
	, html = document.documentElement
	, body = document.body
	, link = /./
	, standalone = "standalone" in navigator ?
		navigator.standalone :
		window.matchMedia && matchMedia("(display-mode:standalone)").matches

	// Detect first available language
	, lang = i18n.use([].concat(
		navigator.languages, navigator.language, navigator.userLanguage,
		"en" // Default language
	).filter(i18n.get)[0])

	// Detect base from HTML <base> element
	, base = (html.getElementsByTagName("base")[0] || i18n).href


	history.scrollRestoration = "manual"
	if (standalone) {
		El.addClass(html, "is-app")
	}


	try {
		timezone = Intl.DateTimeFormat().resolvedOptions().timezone
	} catch(e) {}

	i18n.setLang = function(lang) {
		html.lang = lang = i18n.use(lang)
		xhr.load("lang/" + lang + ".js", function() {
			Date.names = i18n("__date").split(" ")
			String.alphabet = i18n("__alphabet")
			String.ordinal = i18n("__ordinal")
			String.plural = i18n("__plural")
			Object.assign(Date.masks, i18n("__dateMasks"))
			body.dir = i18n("dir")

			El.render(body)
		})
	}


	// Define `#body` view, it is a starting point for us.
	// It could be any element on page but we want to start from `BODY`.
	View("#body", body)

	View.on("show", function(params, view) {
		// Re-render all .js-viewHook elements on each View change
		El.findAll(body, ".js-viewRender").render()
		scroll(0, 0)
	})


	xhr.load(El.findAll(body, "script[type='litejs/view']").pluck("src"), function() {
		// Start a router to show views
		history.start(View.show, base && base.replace(/.*:\/\/[^/]*|[^\/]*$/g, ""))
	})

	El.on(body, "click", function(e) {
		var el = e.target
		, link = !(e.altKey || e.shiftKey) && el.tagName == "A" && el.href.split("#")

		if (link && link[0] == (base || location.href.split("#")[0])) {
			if (e[El.kbMod] ? window.open(el.href, "_blank") : !history.setUrl(link[1])) {
				return Event.stop(e)
			}
		}
	})

	if (window.console && console.log) {
		link.toString = function() {
			return "https://en.wikipedia.org/wiki/Self-XSS"
		}
		console.log(
			"%cStop!\n%cThis developer tool lets you hack and give others access only to your own account.\nSee %s for more information.",
			"font:bold 50px monospace;color:red;text-shadow:3px 3px #000,-1px -1px #fff",
			"font:20px sans-serif",
			link
		)
	}
}(this, document, navigator, View, El.i18n)
